==> react-nlp-annotate-0.1.17.tgz: package/components/NLPAnnotator/index.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useLayoutEffect } from "react";
import SequenceAnnotator from "../SequenceAnnotator";
import DocumentLabeler from "../DocumentLabeler";
import Transcriber from "../Transcriber";
import colors from "../../colors";
import { green } from "@material-ui/core/colors";
import makeStyles from "@material-ui/styles/makeStyles";
import Container from "../Container";
import Button from "@material-ui/core/Button";
var useStyles = makeStyles({
  finishButton: {
    "&&": {
      fontSize: 14,
      textTransform: "none",
      backgroundColor: green[500],
      padding: 10,
      color: "#fff",
      margin: 10,
      fontWeight: "bold",
      "&:hover": {
        backgroundColor: green[700]
      }
    }
  }
});
export default function NLPAnnotator(props) {
  var classes = useStyles();

  var _useState = useState(null),
      _useState2 = _slicedToArray(_useState, 2),
      output = _useState2[0],
      changeOutput = _useState2[1];

  if (output === null && props.type === "transcribe") {
    output = props.initialTranscriptionText;
  }

  if (output === null && props.type === "label-sequence") {
    output = props.initialSequence || [{
      text: props.document
    }];
  }

  useLayoutEffect(function () {
    var eventFunc = function eventFunc(e) {
      if (e.key === "Enter") {
        if (props.onFinish) props.onFinish(output);
      }
    };

    window.addEventListener("keydown", eventFunc);
    return function () {
      window.removeEventListener("keydown", eventFunc);
    };
  });

  var onChange = function onChange(newOutput) {
    if (props.onChange) props.onChange(newOutput);
    changeOutput(newOutput);
  };

  if (props.labels && props.labels.some(function (l) {
    return !l.color;
  })) {
    props = _objectSpread({}, props, {
      labels: props.labels.map(function (l, i) {
        return _objectSpread({
          color: colors[i % colors.length]
        }, l);
      })
    });
  }

  var finishButton = null;

  if (props.onFinish) {
    finishButton = React.createElement(Button, {
      disabled: props.validator && props.validator(output).some(function (msg) {
        return msg.toLowerCase().includes("error:");
      }),
      onClick: function onClick() {
        props.onFinish(output);
      },
      className: classes.finishButton
    }, "Complete (enter)");
  }

  if (props.type === "label-sequence") {
    return React.createElement(Container, null, React.createElement(SequenceAnnotator, Object.assign({}, props, {
      onChange: onChange
    })), React.createElement("div", {
      style: {
        textAlign: "right"
      }
    }, finishButton));
  }

  if (props.type === "label-document") {
    return React.createElement(Container, null, React.createElement(DocumentLabeler, Object.assign({}, props, {
      onChange: onChange
    })), React.createElement("div", {
      style: {
        textAlign: "right"
      }
    }, finishButton));
  }

  if (props.type === "transcribe") {
    return React.createElement(Container, null, React.createElement(Transcriber, Object.assign({}, props, {
      onChange: onChange
    })), React.createElement("div", {
      style: {
        textAlign: "right"
      }
    }, finishButton));
  }

  return null;
}

==> react-nlp-annotate-0.1.22.tgz: package/components/NLPAnnotator/index.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useLayoutEffect } from "react";
import SequenceAnnotator from "../SequenceAnnotator";
import DocumentLabeler from "../DocumentLabeler";
import Transcriber from "../Transcriber";
import colors from "../../colors";
import { green } from "@material-ui/core/colors";
import makeStyles from "@material-ui/styles/makeStyles";
import Container from "../Container";
import Button from "@material-ui/core/Button";
var useStyles = makeStyles({
  finishButton: {
    "&&": {
      fontSize: 14,
      textTransform: "none",
      backgroundColor: green[500],
      padding: 10,
      color: "#fff",
      margin: 10,
      fontWeight: "bold",
      "&:hover": {
        backgroundColor: green[700]
      }
    }
  }
});
export default function NLPAnnotator(props) {
  var classes = useStyles();

  var _useState = useState(null),
      _useState2 = _slicedToArray(_useState, 2),
      output = _useState2[0],
      changeOutput = _useState2[1];

  if (output === null && props.type === "transcribe") {
    output = props.initialTranscriptionText;
  }

  if (output === null && props.type === "label-sequence") {
    output = props.initialSequence || [{
      text: props.document
    }];
  }

  useLayoutEffect(function () {
    var eventFunc = function eventFunc(e) {
      if (e.key === "Enter") {
        if (props.onFinish) props.onFinish(output);
      }
    };

    window.addEventListener("keydown", eventFunc);
    return function () {
      window.removeEventListener("keydown", eventFunc);
    };
  });

  var onChange = function onChange(newOutput) {
    if (props.onChange) props.onChange(newOutput);
    changeOutput(newOutput);
  };

  if (props.labels && props.labels.some(function (l) {
    return !l.color;
  })) {
    props = _objectSpread({}, props, {
      labels: props.labels.map(function (l, i) {
        return _objectSpread({
          color: colors[i % colors.length]
        }, l);
      })
    });
  }

  var finishButton = null;

  if (props.onFinish) {
    finishButton = /*#__PURE__*/React.createElement(Button, {
      disabled: props.validator && props.validator(output).some(function (msg) {
        return msg.toLowerCase().includes("error:");
      }),
      onClick: function onClick() {
        props.onFinish(output);
      },
      className: classes.finishButton
    }, "Complete (enter)");
  }

  if (props.type === "label-sequence") {
    return /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(SequenceAnnotator, Object.assign({}, props, {
      onChange: onChange
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        textAlign: "right"
      }
    }, finishButton));
  }

  if (props.type === "label-document") {
    return /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(DocumentLabeler, Object.assign({}, props, {
      onChange: onChange
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        textAlign: "right"
      }
    }, finishButton));
  }

  if (props.type === "transcribe") {
    return /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Transcriber, Object.assign({}, props, {
      onChange: onChange
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        textAlign: "right"
      }
    }, finishButton));
  }

  return null;
}
